app_realtime_ext library

A package to extend Appwrite Realtime

Classes

ConnectedState
A state indicating that the Realtime is connected
ConnectingState
A state indicating that the Realtime is connecting
CookieManagerExt
An interceptor that manages cookies.
DisconnectedState
A state indicating that the Realtime is disconnected
DisposingState
A state indicating that the Realtime is disposing
ErrorState
A state indicating that the Realtime has encountered an error
HeadersInterceptorExt
An interceptor that adds headers to a request.
InterceptorExt
An extension of the InterceptorExt class that allows for more customization.
PingState
A state indicating that the Realtime is pinging
RealtimeBaseExt
Realtime allows you to listen to any events on the server-side in realtime using the subscribe method.
RealtimeExt
A Realtime Clone from Appwrite Flutter sdk. The purpose of this is to extend the capability and separate from sdk-generator
RealtimeResponseConnectedExt
The response of the connected event
RealtimeResponseExt
The realtime response from the server
RealtimeState
The State of the Realtime
RealtimeSubscriptionExt
Realtime Subscription
ReconnectingState
A state indicating that the Realtime is reconnecting
SubscribingState
A state indicating that the Realtime is going to subscribe with channels
UnSubscribingState
A state indicating that the Realtime is going to close a specific subscription

Enums

RealtimeResponseType
The type of the realtime response

Mixins

RealtimeMixinExt
Mixin for Realtime

Functions

createRealtime() RealtimeBaseExt
Implemented in realtime_browser.dart and realtime_io.dart.

Typedefs

GetFallbackCookie = String? Function()
Typed function to get a fallback cookie
WebSocketFactory = Future<WebSocketChannel> Function(Uri uri)
Typed function to create a WebSocketChannel

Exceptions / Errors

AppRealtimeException
An exception class for AppRealtime